@@ -48,7 +48,6 @@ tests = {'1': ('Start a single bootstrap and downloader, test updating and downl
               (1, ['install', 'ada-reference-manual']),
               (1, ['install', 'aspectj-doc']),
               (1, ['install', 'fop-doc']),
-              (1, ['install', 'asis-doc']),
               (1, ['install', 'bison-doc']),
               (1, ['install', 'crash-whitepaper']),
               ]),
@@ -166,9 +165,9 @@ tests = {'1': ('Start a single bootstrap and downloader, test updating and downl
              {1: {}},
              [(1, ['update']), 
               (1, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
@@ -185,54 +184,54 @@ tests = {'1': ('Start a single bootstrap and downloader, test updating and downl
               6: {}},
              [(1, ['update']), 
               (1, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
                    ]),
               (2, ['update']), 
               (2, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
                    ]),
               (3, ['update']), 
               (3, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
                    ]),
               (4, ['update']), 
               (4, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
                    ]),
               (5, ['update']), 
               (5, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
                    ]),
               (6, ['update']), 
               (6, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
@@ -267,9 +266,9 @@ tests = {'1': ('Start a single bootstrap and downloader, test updating and downl
              {1: {'clean': False},
               2: {'clean': False}},
             [(1, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
@@ -277,25 +276,25 @@ tests = {'1': ('Start a single bootstrap and downloader, test updating and downl
               (1, ['update']), 
               (1, ['update']), 
               (1, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
                    ]),
               (1, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
                    ]),
               (2, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
@@ -303,17 +302,17 @@ tests = {'1': ('Start a single bootstrap and downloader, test updating and downl
               (2, ['update']), 
               (2, ['update']), 
               (2, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
                    ]),
               (2, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
@@ -347,14 +346,14 @@ tests = {'1': ('Start a single bootstrap and downloader, test updating and downl
              [(1, ['update']), 
               (1, ['install', 'aboot-base', 'ada-reference-manual',
                    'fop-doc', 'bison-doc', 'crash-whitepaper',
-                   'apt-howto-common', 'aptitude-doc-en', 'asr-manpages',
+                   'aptitude-doc-en', 'asr-manpages',
                    'alcovebook-sgml-doc', 'airstrike-common',
                    ]),
               (2, ['update']), 
               (2, ['install', 'aboot-base', 'aap-doc', 'ada-reference-manual',
-                   'aspectj-doc', 'fop-doc', 'asis-doc',
+                   'aspectj-doc', 'fop-doc',
                    'bison-doc', 'crash-whitepaper',
-                   'bash-doc', 'apt-howto-common', 'autotools-dev',
+                   'autotools-dev',
                    'aptitude-doc-en', 'asr-manpages',
                    'atomix-data', 'alcovebook-sgml-doc',
                    'afbackup-common', 'airstrike-common',
